==> mcu_plus_sdk_am64x_07_03_00_19_docs_only.tar.xz: mcu_plus_sdk_am64x_07_03_00_19_docs_only/docs/api_guide_am64x/group__DRV__IPC__RPMESSAGE__MODULE.js <==
var group__DRV__IPC__RPMESSAGE__MODULE =
[
    [ "RPMessage_Object", "structRPMessage__Object.html", [
      [ "rsv", "structRPMessage__Object.html#acff84c2c3b40146f7da029931a9a6b67", null ]
    ] ],
    [ "RPMessage_CreateParams", "structRPMessage__CreateParams.html", [
      [ "localEndPt", "structRPMessage__CreateParams.html#ad4e5fe99c906858d45338d428ececf93", null ],
      [ "recvCallback", "structRPMessage__CreateParams.html#a3ff04a01425e0e9f54658fc3087ab6fb", null ],
      [ "recvCallbackArgs", "structRPMessage__CreateParams.html#a500c2e73c954fa2a00199bf706daa839", null ]
    ] ],
    [ "RPMessage_Params", "structRPMessage__Params.html", [
      [ "vringTxBaseAddr", "structRPMessage__Params.html#acac88d90d3adaf0ab45a7ce95882eb19", null ],
      [ "vringRxBaseAddr", "structRPMessage__Params.html#a2aa1c041d778c80b5db9c5d854f105cc", null ],
      [ "vringSize", "structRPMessage__Params.html#af894aa745563cde9181059e3a11d773c", null ],
      [ "vringNumBuf", "structRPMessage__Params.html#aa59be9cdd57fe409346ba910ed2d8736", null ],
      [ "vringMsgSize", "structRPMessage__Params.html#a2323a73d6a7ea3476b8f0a54db22a0b4", null ],
      [ "linuxResourceTable", "structRPMessage__Params.html#a4a3b5a47ad95ce26f01eadc790d02c3c", null ],
      [ "linuxCoreId", "structRPMessage__Params.html#a8b0ea61d351498cf0750cf706099f9f9", null ]
    ] ],
    [ "RPMESSAGE_MAX_LOCAL_ENDPT", "group__DRV__IPC__RPMESSAGE__MODULE.html#gaf4060d0190661b273717e068abbdff8c", null ],
    [ "RPMESSAGE_VRING_ADDR_INVALID", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga6e71db0232ba0a13336afc3b485fb674", null ],
    [ "RPMESSAGE_VRING_SIZE", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga566526f59d13dd3dc94bade124343d21", null ],
    [ "RPMESSAGE_OBJECT_SIZE_MAX", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga3166c49b8819ea42beec09dd29dc7dcc", null ],
    [ "RPMessage_RecvCallback", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga838d61fef6baad9d306f073a190e96b6", null ],
    [ "RPMessage_ControlEndPtCallback", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga4e771094723cb4f1ce4f5d3acad508e1", null ],
    [ "RPMessage_Params_init", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga353a4139549fa6733571cc3189b658bd", null ],
    [ "RPMessage_CreateParams_init", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga243ad0c7f5653e91410566c5d548d6f1", null ],
    [ "RPMessage_init", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga11518ab5595c5ac2d1233e946fa89536", null ],
    [ "RPMessage_deInit", "group__DRV__IPC__RPMESSAGE__MODULE.html#gaf7eed37da5b4e1879ba58488af2cbe54", null ],
    [ "RPMessage_waitForLinuxReady", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga6a1f6307291e52b3221887ef299fd9e8", null ],
    [ "RPMessage_controlEndPtCallback", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga041facc97d3b95f0d07d9d3e0ce8b55e", null ],
    [ "RPMessage_construct", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga3f4755622a1a85b816b156f11ab126e3", null ],
    [ "RPMessage_destruct", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga7817f068fc1080aad7a6947079e73f9e", null ],
    [ "RPMessage_unblock", "group__DRV__IPC__RPMESSAGE__MODULE.html#gacfb174282fa8ab0f20812df2f1d7ef69", null ],
    [ "RPMessage_getLocalEndPt", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga3f5a806cd00de417cf067f324e221ef8", null ],
    [ "RPMessage_announce", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga765b5dc385428277e0f0ce8f374e5f47", null ],
    [ "RPMessage_send", "group__DRV__IPC__RPMESSAGE__MODULE.html#gaa1b08e6316921caa469982a34c06841b", null ],
    [ "RPMessage_recv", "group__DRV__IPC__RPMESSAGE__MODULE.html#gaff81ed42f1cbf0d5118bafef6a0b7add", null ]
];

==> mcu_plus_sdk_am64x_08_00_00_21_docs_only.tar.xz: mcu_plus_sdk_am64x_08_00_00_21_docs_only/docs/api_guide_am64x/group__DRV__IPC__RPMESSAGE__MODULE.js <==
var group__DRV__IPC__RPMESSAGE__MODULE =
[
    [ "RPMessage_Object", "structRPMessage__Object.html", [
      [ "rsv", "structRPMessage__Object.html#acff84c2c3b40146f7da029931a9a6b67", null ]
    ] ],
    [ "RPMessage_CreateParams", "structRPMessage__CreateParams.html", [
      [ "localEndPt", "structRPMessage__CreateParams.html#ad4e5fe99c906858d45338d428ececf93", null ],
      [ "recvCallback", "structRPMessage__CreateParams.html#a3ff04a01425e0e9f54658fc3087ab6fb", null ],
      [ "recvCallbackArgs", "structRPMessage__CreateParams.html#a500c2e73c954fa2a00199bf706daa839", null ],
      [ "recvNotifyCallback", "structRPMessage__CreateParams.html#a331b016644a0517e2a97a169cb617045", null ],
      [ "recvNotifyCallbackArgs", "structRPMessage__CreateParams.html#abc4380f517b133558f17bf5384e9ecb0", null ]
    ] ],
    [ "RPMessage_Params", "structRPMessage__Params.html", [
      [ "vringTxBaseAddr", "structRPMessage__Params.html#acac88d90d3adaf0ab45a7ce95882eb19", null ],
      [ "vringRxBaseAddr", "structRPMessage__Params.html#a2aa1c041d778c80b5db9c5d854f105cc", null ],
      [ "vringSize", "structRPMessage__Params.html#af894aa745563cde9181059e3a11d773c", null ],
      [ "vringNumBuf", "structRPMessage__Params.html#aa59be9cdd57fe409346ba910ed2d8736", null ],
      [ "vringMsgSize", "structRPMessage__Params.html#a2323a73d6a7ea3476b8f0a54db22a0b4", null ],
      [ "linuxResourceTable", "structRPMessage__Params.html#a4a3b5a47ad95ce26f01eadc790d02c3c", null ],
      [ "linuxCoreId", "structRPMessage__Params.html#a8b0ea61d351498cf0750cf706099f9f9", null ]
    ] ],
    [ "RPMESSAGE_MAX_LOCAL_ENDPT", "group__DRV__IPC__RPMESSAGE__MODULE.html#gaf4060d0190661b273717e068abbdff8c", null ],
    [ "RPMESSAGE_VRING_ADDR_INVALID", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga6e71db0232ba0a13336afc3b485fb674", null ],
    [ "RPMESSAGE_VRING_SIZE", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga566526f59d13dd3dc94bade124343d21", null ],
    [ "RPMESSAGE_OBJECT_SIZE_MAX", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga3166c49b8819ea42beec09dd29dc7dcc", null ],
    [ "RPMessage_RecvCallback", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga838d61fef6baad9d306f073a190e96b6", null ],
    [ "RPMessage_RecvNotifyCallback", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga254b1e2a0a75e5c7b8de583739d8cc92", null ],
    [ "RPMessage_ControlEndPtCallback", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga4e771094723cb4f1ce4f5d3acad508e1", null ],
    [ "RPMessage_Params_init", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga353a4139549fa6733571cc3189b658bd", null ],
    [ "RPMessage_CreateParams_init", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga243ad0c7f5653e91410566c5d548d6f1", null ],
    [ "RPMessage_init", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga11518ab5595c5ac2d1233e946fa89536", null ],
    [ "RPMessage_deInit", "group__DRV__IPC__RPMESSAGE__MODULE.html#gaf7eed37da5b4e1879ba58488af2cbe54", null ],
    [ "RPMessage_waitForLinuxReady", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga6a1f6307291e52b3221887ef299fd9e8", null ],
    [ "RPMessage_controlEndPtCallback", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga041facc97d3b95f0d07d9d3e0ce8b55e", null ],
    [ "RPMessage_construct", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga3f4755622a1a85b816b156f11ab126e3", null ],
    [ "RPMessage_destruct", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga7817f068fc1080aad7a6947079e73f9e", null ],
    [ "RPMessage_unblock", "group__DRV__IPC__RPMESSAGE__MODULE.html#gacfb174282fa8ab0f20812df2f1d7ef69", null ],
    [ "RPMessage_getLocalEndPt", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga3f5a806cd00de417cf067f324e221ef8", null ],
    [ "RPMessage_announce", "group__DRV__IPC__RPMESSAGE__MODULE.html#ga765b5dc385428277e0f0ce8f374e5f47", null ],
    [ "RPMessage_send", "group__DRV__IPC__RPMESSAGE__MODULE.html#gaa1b08e6316921caa469982a34c06841b", null ],
    [ "RPMessage_recv", "group__DRV__IPC__RPMESSAGE__MODULE.html#gaff81ed42f1cbf0d5118bafef6a0b7add", null ]
];
